<?php
/**
 * A deck class for cars with ramps and about 2.5 meters hich
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link 		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class CarDeck extends BaseDeck implements TradeableItem, ConstructableShipPart {
	// Konstruktor
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set description
		$this->setObjectDescription("Autodeck");

		// Generate unique ID number
		$this->createUniqueID();

		// Clean up a little
		$this->removeSystemArray();
	}

	// Autodeck erstellen
	public final static function createCarDeck ($numDecks, $dim) {
		// Get new instance
		$carInstance = new CarDeck();

		// Debug message
		if ((defined('DEBUG_DECK')) || (defined('DEBUG_ALL'))) $carInstance->getDebugInstance()->output(sprintf("[%s:%d] Ein Autodeck wird konstruiert...<br />\n",
			__CLASS__,
			__LINE__
		));

		// Abmasse extrahieren
		$carInstance->extractDimensions($dim);

		// Andere Daten uebetragen
		$carInstance->setNumDecks($numDecks);

		// Nicht noetige Instanz
		$carInstance->removePartInstance();

		// Instanz zurueckgeben
		return $carInstance;
	}

	// Overwritten method for tradeable items
	public function isTradeable () {
		return true;
	}

	/**
	 * Limits this object with an ObjectLimits instance
	 */
	public function limitObject (ObjectLimits $limitInstance) {
		ApplicationEntryPoint::app_die("".__METHOD__." reached! Stub!");
	}
}

// [EOF]
?>
