<?php
/**
 * The default controller with news for e.g. home or news page
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class WebDefaultNewsController extends BaseController implements Controller {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set part description
		$this->setObjectDescription("Standart-Controller mit News-Auflistung");

		// Create unique ID number
		$this->createUniqueID();
	}

	/**
	 * Creates an instance of this class
	 *
	 * @param	$resolverInstance		An instance of a command resolver class
	 * @return	$controllerInstance		A prepared instance of this class
	 */
	public final static function createWebDefaultNewsController (CommandResolver $resolverInstance) {
		// Create the instance
		$controllerInstance = new WebDefaultNewsController();

		// Set the command resolver
		$controllerInstance->setResolverInstance($resolverInstance);

		// Return the prepared instance
		return $controllerInstance;
	}

	/**
	 * Handles the given request and response
	 *
	 * @param	$requestInstance	An instance of a request class
	 * @param	$responseInstance	An instance of a response class
	 * @return	void
	 */
	public function handleRequest (Requestable $requestInstance, Responseable $responseInstance) {
		// Get the command instance from the resolver by sending a request instance to the resolver
		$commandInstance = $this->getResolverInstance()->resolvCommandByRequest($requestInstance);

		// Load the news here
		$this->loadNewsByRequest($requestInstance);

		// Execute the command
		$commandInstance->execute($requestInstance, $responseInstance);

		// Flush the response out
		$responseInstance->flushBuffer();
	}

	/**
	 * Loads news by a given request
	 *
	 * @param	$requestInstance	An instance of a request class
	 * @return	void
	 */
	private function loadNewsByRequest (Requestable $requestInstance) {
		// Generate a new news object but not carring about which concrete we have
		$newsInstance = NewsFactory::createFactoryByRequest($requestInstance)->createNewsObject();
	}
}

// [EOF]
?>
