<?php
/**
 * A generic helper class with generic methods
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class BaseHelper extends BaseFrameworkSystem {
	/**
	 * Template engine instance
	 */
	private $templateInstance = null;

	/**
	 * Rendered content created by the helper class
	 */
	private $content = "";

	/**
	 * Private constructor
	 *
	 * @param	$className	Real name of the class
	 * @return	void
	 */
	protected function __construct ($className) {
		// Call parent constructor
		parent::__construct($className);

		// Create unique ID number
		$this->createUniqueID();

		// Clean up a little
		$this->removeNumberFormaters();
		$this->removeSystemArray();
	}

	/**
	 * Setter for template engine instances
	 *
	 * @param	$templateInstance	An instance of a template engine class
	 * @return	void
	 */
	protected final function setTemplateInstance (CompileableTemplate $templateInstance) {
		$this->templateInstance = $templateInstance;
	}

	/**
	 * Getter for template engine instances
	 *
	 * @return	$templateInstance	An instance of a template engine class
	 */
	protected final function getTemplateInstance () {
		return $this->templateInstance;
	}

	/**
	 * Add content
	 *
	 * @param	$newContent		New content to add
	 * @return	void
	 */
	protected final function addContent ($newContent) {
		$this->content .= (string) trim($newContent)."\r\n";
	}

	/**
	 * Getter for content
	 *
	 * @return	$content	The rendered content by this helper
	 */
	protected final function getContent () {
		return $this->content;
	}
}

// [EOF]
?>
